# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEndpointGroupIpAddressCidrBlocksResult',
    'AwaitableGetEndpointGroupIpAddressCidrBlocksResult',
    'get_endpoint_group_ip_address_cidr_blocks',
    'get_endpoint_group_ip_address_cidr_blocks_output',
]

@pulumi.output_type
class GetEndpointGroupIpAddressCidrBlocksResult:
    """
    A collection of values returned by getEndpointGroupIpAddressCidrBlocks.
    """
    def __init__(__self__, accelerator_id=None, endpoint_group_ip_address_cidr_blocks=None, endpoint_group_region=None, id=None, output_file=None):
        if accelerator_id and not isinstance(accelerator_id, str):
            raise TypeError("Expected argument 'accelerator_id' to be a str")
        pulumi.set(__self__, "accelerator_id", accelerator_id)
        if endpoint_group_ip_address_cidr_blocks and not isinstance(endpoint_group_ip_address_cidr_blocks, list):
            raise TypeError("Expected argument 'endpoint_group_ip_address_cidr_blocks' to be a list")
        pulumi.set(__self__, "endpoint_group_ip_address_cidr_blocks", endpoint_group_ip_address_cidr_blocks)
        if endpoint_group_region and not isinstance(endpoint_group_region, str):
            raise TypeError("Expected argument 'endpoint_group_region' to be a str")
        pulumi.set(__self__, "endpoint_group_region", endpoint_group_region)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> Optional[str]:
        return pulumi.get(self, "accelerator_id")

    @property
    @pulumi.getter(name="endpointGroupIpAddressCidrBlocks")
    def endpoint_group_ip_address_cidr_blocks(self) -> Sequence['outputs.GetEndpointGroupIpAddressCidrBlocksEndpointGroupIpAddressCidrBlockResult']:
        """
        A list of Endpoint Group Ip Address Cidr Blocks. Each element contains the following attributes:
        """
        return pulumi.get(self, "endpoint_group_ip_address_cidr_blocks")

    @property
    @pulumi.getter(name="endpointGroupRegion")
    def endpoint_group_region(self) -> str:
        """
        The region ID of the endpoint group.
        """
        return pulumi.get(self, "endpoint_group_region")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetEndpointGroupIpAddressCidrBlocksResult(GetEndpointGroupIpAddressCidrBlocksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointGroupIpAddressCidrBlocksResult(
            accelerator_id=self.accelerator_id,
            endpoint_group_ip_address_cidr_blocks=self.endpoint_group_ip_address_cidr_blocks,
            endpoint_group_region=self.endpoint_group_region,
            id=self.id,
            output_file=self.output_file)


def get_endpoint_group_ip_address_cidr_blocks(accelerator_id: Optional[str] = None,
                                              endpoint_group_region: Optional[str] = None,
                                              output_file: Optional[str] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointGroupIpAddressCidrBlocksResult:
    """
    This data source provides the Global Accelerator (GA) Endpoint Group Ip Address Cidr Blocks of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.213.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.ga.get_endpoint_group_ip_address_cidr_blocks(endpoint_group_region="cn-hangzhou")
    pulumi.export("gaEndpointGroupIpAddressCidrBlocksEndpointGroupRegion", default.endpoint_group_ip_address_cidr_blocks[0].endpoint_group_region)
    ```


    :param str accelerator_id: The ID of the Global Accelerator (GA) instance.
    :param str endpoint_group_region: The region ID of the endpoint group.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointGroupRegion'] = endpoint_group_region
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getEndpointGroupIpAddressCidrBlocks:getEndpointGroupIpAddressCidrBlocks', __args__, opts=opts, typ=GetEndpointGroupIpAddressCidrBlocksResult).value

    return AwaitableGetEndpointGroupIpAddressCidrBlocksResult(
        accelerator_id=pulumi.get(__ret__, 'accelerator_id'),
        endpoint_group_ip_address_cidr_blocks=pulumi.get(__ret__, 'endpoint_group_ip_address_cidr_blocks'),
        endpoint_group_region=pulumi.get(__ret__, 'endpoint_group_region'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_endpoint_group_ip_address_cidr_blocks_output(accelerator_id: Optional[pulumi.Input[Optional[str]]] = None,
                                                     endpoint_group_region: Optional[pulumi.Input[str]] = None,
                                                     output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEndpointGroupIpAddressCidrBlocksResult]:
    """
    This data source provides the Global Accelerator (GA) Endpoint Group Ip Address Cidr Blocks of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.213.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.ga.get_endpoint_group_ip_address_cidr_blocks(endpoint_group_region="cn-hangzhou")
    pulumi.export("gaEndpointGroupIpAddressCidrBlocksEndpointGroupRegion", default.endpoint_group_ip_address_cidr_blocks[0].endpoint_group_region)
    ```


    :param str accelerator_id: The ID of the Global Accelerator (GA) instance.
    :param str endpoint_group_region: The region ID of the endpoint group.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointGroupRegion'] = endpoint_group_region
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ga/getEndpointGroupIpAddressCidrBlocks:getEndpointGroupIpAddressCidrBlocks', __args__, opts=opts, typ=GetEndpointGroupIpAddressCidrBlocksResult)
    return __ret__.apply(lambda __response__: GetEndpointGroupIpAddressCidrBlocksResult(
        accelerator_id=pulumi.get(__response__, 'accelerator_id'),
        endpoint_group_ip_address_cidr_blocks=pulumi.get(__response__, 'endpoint_group_ip_address_cidr_blocks'),
        endpoint_group_region=pulumi.get(__response__, 'endpoint_group_region'),
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceAttachmentArgs', 'InstanceAttachment']

@pulumi.input_type
class InstanceAttachmentArgs:
    def __init__(__self__, *,
                 child_instance_id: pulumi.Input[str],
                 child_instance_region_id: pulumi.Input[str],
                 child_instance_type: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 cen_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a InstanceAttachment resource.
        :param pulumi.Input[str] child_instance_id: The ID of the child instance to attach.
        :param pulumi.Input[str] child_instance_region_id: The region ID of the child instance to attach.
        :param pulumi.Input[str] child_instance_type: The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        :param pulumi.Input[str] instance_id: The ID of the CEN.
        :param pulumi.Input[int] cen_owner_id: The account ID to which the CEN instance belongs.
               
               ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        :param pulumi.Input[int] child_instance_owner_id: The uid of the child instance. Only used when attach a child instance of other account.
        """
        pulumi.set(__self__, "child_instance_id", child_instance_id)
        pulumi.set(__self__, "child_instance_region_id", child_instance_region_id)
        pulumi.set(__self__, "child_instance_type", child_instance_type)
        pulumi.set(__self__, "instance_id", instance_id)
        if cen_owner_id is not None:
            pulumi.set(__self__, "cen_owner_id", cen_owner_id)
        if child_instance_owner_id is not None:
            pulumi.set(__self__, "child_instance_owner_id", child_instance_owner_id)

    @property
    @pulumi.getter(name="childInstanceId")
    def child_instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the child instance to attach.
        """
        return pulumi.get(self, "child_instance_id")

    @child_instance_id.setter
    def child_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "child_instance_id", value)

    @property
    @pulumi.getter(name="childInstanceRegionId")
    def child_instance_region_id(self) -> pulumi.Input[str]:
        """
        The region ID of the child instance to attach.
        """
        return pulumi.get(self, "child_instance_region_id")

    @child_instance_region_id.setter
    def child_instance_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "child_instance_region_id", value)

    @property
    @pulumi.getter(name="childInstanceType")
    def child_instance_type(self) -> pulumi.Input[str]:
        """
        The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        """
        return pulumi.get(self, "child_instance_type")

    @child_instance_type.setter
    def child_instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "child_instance_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the CEN.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="cenOwnerId")
    def cen_owner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The account ID to which the CEN instance belongs.

        ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        """
        return pulumi.get(self, "cen_owner_id")

    @cen_owner_id.setter
    def cen_owner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cen_owner_id", value)

    @property
    @pulumi.getter(name="childInstanceOwnerId")
    def child_instance_owner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The uid of the child instance. Only used when attach a child instance of other account.
        """
        return pulumi.get(self, "child_instance_owner_id")

    @child_instance_owner_id.setter
    def child_instance_owner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "child_instance_owner_id", value)


@pulumi.input_type
class _InstanceAttachmentState:
    def __init__(__self__, *,
                 cen_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_id: Optional[pulumi.Input[str]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_region_id: Optional[pulumi.Input[str]] = None,
                 child_instance_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering InstanceAttachment resources.
        :param pulumi.Input[int] cen_owner_id: The account ID to which the CEN instance belongs.
               
               ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        :param pulumi.Input[str] child_instance_id: The ID of the child instance to attach.
        :param pulumi.Input[int] child_instance_owner_id: The uid of the child instance. Only used when attach a child instance of other account.
        :param pulumi.Input[str] child_instance_region_id: The region ID of the child instance to attach.
        :param pulumi.Input[str] child_instance_type: The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        :param pulumi.Input[str] instance_id: The ID of the CEN.
        :param pulumi.Input[str] status: The associating status of the network.
        """
        if cen_owner_id is not None:
            pulumi.set(__self__, "cen_owner_id", cen_owner_id)
        if child_instance_id is not None:
            pulumi.set(__self__, "child_instance_id", child_instance_id)
        if child_instance_owner_id is not None:
            pulumi.set(__self__, "child_instance_owner_id", child_instance_owner_id)
        if child_instance_region_id is not None:
            pulumi.set(__self__, "child_instance_region_id", child_instance_region_id)
        if child_instance_type is not None:
            pulumi.set(__self__, "child_instance_type", child_instance_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="cenOwnerId")
    def cen_owner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The account ID to which the CEN instance belongs.

        ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        """
        return pulumi.get(self, "cen_owner_id")

    @cen_owner_id.setter
    def cen_owner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cen_owner_id", value)

    @property
    @pulumi.getter(name="childInstanceId")
    def child_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the child instance to attach.
        """
        return pulumi.get(self, "child_instance_id")

    @child_instance_id.setter
    def child_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_id", value)

    @property
    @pulumi.getter(name="childInstanceOwnerId")
    def child_instance_owner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The uid of the child instance. Only used when attach a child instance of other account.
        """
        return pulumi.get(self, "child_instance_owner_id")

    @child_instance_owner_id.setter
    def child_instance_owner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "child_instance_owner_id", value)

    @property
    @pulumi.getter(name="childInstanceRegionId")
    def child_instance_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region ID of the child instance to attach.
        """
        return pulumi.get(self, "child_instance_region_id")

    @child_instance_region_id.setter
    def child_instance_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_region_id", value)

    @property
    @pulumi.getter(name="childInstanceType")
    def child_instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        """
        return pulumi.get(self, "child_instance_type")

    @child_instance_type.setter
    def child_instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "child_instance_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the CEN.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The associating status of the network.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class InstanceAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_id: Optional[pulumi.Input[str]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_region_id: Optional[pulumi.Input[str]] = None,
                 child_instance_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a CEN child instance attachment resource that associate the network(VPC, CCN, VBR) with the CEN instance.

        > **NOTE:** Available since v1.42.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_regions(current=True)
        example = alicloud.vpc.Network("example",
            vpc_name="tf_example",
            cidr_block="172.17.3.0/24")
        example_instance = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_instance_attachment = alicloud.cen.InstanceAttachment("example",
            instance_id=example_instance.id,
            child_instance_id=example.id,
            child_instance_type="VPC",
            child_instance_region_id=default.regions[0].id)
        ```

        ## Import

        CEN instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/instanceAttachment:InstanceAttachment example cen-m7i7pjmkon********:vpc-2ze2w07mcy9nz********:VPC:cn-beijing
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] cen_owner_id: The account ID to which the CEN instance belongs.
               
               ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        :param pulumi.Input[str] child_instance_id: The ID of the child instance to attach.
        :param pulumi.Input[int] child_instance_owner_id: The uid of the child instance. Only used when attach a child instance of other account.
        :param pulumi.Input[str] child_instance_region_id: The region ID of the child instance to attach.
        :param pulumi.Input[str] child_instance_type: The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        :param pulumi.Input[str] instance_id: The ID of the CEN.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a CEN child instance attachment resource that associate the network(VPC, CCN, VBR) with the CEN instance.

        > **NOTE:** Available since v1.42.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_regions(current=True)
        example = alicloud.vpc.Network("example",
            vpc_name="tf_example",
            cidr_block="172.17.3.0/24")
        example_instance = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_instance_attachment = alicloud.cen.InstanceAttachment("example",
            instance_id=example_instance.id,
            child_instance_id=example.id,
            child_instance_type="VPC",
            child_instance_region_id=default.regions[0].id)
        ```

        ## Import

        CEN instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/instanceAttachment:InstanceAttachment example cen-m7i7pjmkon********:vpc-2ze2w07mcy9nz********:VPC:cn-beijing
        ```

        :param str resource_name: The name of the resource.
        :param InstanceAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_id: Optional[pulumi.Input[str]] = None,
                 child_instance_owner_id: Optional[pulumi.Input[int]] = None,
                 child_instance_region_id: Optional[pulumi.Input[str]] = None,
                 child_instance_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceAttachmentArgs.__new__(InstanceAttachmentArgs)

            __props__.__dict__["cen_owner_id"] = cen_owner_id
            if child_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'child_instance_id'")
            __props__.__dict__["child_instance_id"] = child_instance_id
            __props__.__dict__["child_instance_owner_id"] = child_instance_owner_id
            if child_instance_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'child_instance_region_id'")
            __props__.__dict__["child_instance_region_id"] = child_instance_region_id
            if child_instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'child_instance_type'")
            __props__.__dict__["child_instance_type"] = child_instance_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["status"] = None
        super(InstanceAttachment, __self__).__init__(
            'alicloud:cen/instanceAttachment:InstanceAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cen_owner_id: Optional[pulumi.Input[int]] = None,
            child_instance_id: Optional[pulumi.Input[str]] = None,
            child_instance_owner_id: Optional[pulumi.Input[int]] = None,
            child_instance_region_id: Optional[pulumi.Input[str]] = None,
            child_instance_type: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'InstanceAttachment':
        """
        Get an existing InstanceAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] cen_owner_id: The account ID to which the CEN instance belongs.
               
               ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        :param pulumi.Input[str] child_instance_id: The ID of the child instance to attach.
        :param pulumi.Input[int] child_instance_owner_id: The uid of the child instance. Only used when attach a child instance of other account.
        :param pulumi.Input[str] child_instance_region_id: The region ID of the child instance to attach.
        :param pulumi.Input[str] child_instance_type: The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        :param pulumi.Input[str] instance_id: The ID of the CEN.
        :param pulumi.Input[str] status: The associating status of the network.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceAttachmentState.__new__(_InstanceAttachmentState)

        __props__.__dict__["cen_owner_id"] = cen_owner_id
        __props__.__dict__["child_instance_id"] = child_instance_id
        __props__.__dict__["child_instance_owner_id"] = child_instance_owner_id
        __props__.__dict__["child_instance_region_id"] = child_instance_region_id
        __props__.__dict__["child_instance_type"] = child_instance_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["status"] = status
        return InstanceAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cenOwnerId")
    def cen_owner_id(self) -> pulumi.Output[Optional[int]]:
        """
        The account ID to which the CEN instance belongs.

        ->**NOTE:** Ensure that the child instance is not used in Express Connect.
        """
        return pulumi.get(self, "cen_owner_id")

    @property
    @pulumi.getter(name="childInstanceId")
    def child_instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the child instance to attach.
        """
        return pulumi.get(self, "child_instance_id")

    @property
    @pulumi.getter(name="childInstanceOwnerId")
    def child_instance_owner_id(self) -> pulumi.Output[int]:
        """
        The uid of the child instance. Only used when attach a child instance of other account.
        """
        return pulumi.get(self, "child_instance_owner_id")

    @property
    @pulumi.getter(name="childInstanceRegionId")
    def child_instance_region_id(self) -> pulumi.Output[str]:
        """
        The region ID of the child instance to attach.
        """
        return pulumi.get(self, "child_instance_region_id")

    @property
    @pulumi.getter(name="childInstanceType")
    def child_instance_type(self) -> pulumi.Output[str]:
        """
        The type of the associated network. Valid values: `VPC`, `VBR` and `CCN`.
        """
        return pulumi.get(self, "child_instance_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the CEN.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The associating status of the network.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HadoopDataSourceArgs', 'HadoopDataSource']

@pulumi.input_type
class HadoopDataSourceArgs:
    def __init__(__self__, *,
                 db_instance_id: pulumi.Input[str],
                 data_source_description: Optional[pulumi.Input[str]] = None,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 data_source_type: Optional[pulumi.Input[str]] = None,
                 emr_instance_id: Optional[pulumi.Input[str]] = None,
                 hadoop_core_conf: Optional[pulumi.Input[str]] = None,
                 hadoop_create_type: Optional[pulumi.Input[str]] = None,
                 hadoop_hosts_address: Optional[pulumi.Input[str]] = None,
                 hdfs_conf: Optional[pulumi.Input[str]] = None,
                 hive_conf: Optional[pulumi.Input[str]] = None,
                 map_reduce_conf: Optional[pulumi.Input[str]] = None,
                 yarn_conf: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a HadoopDataSource resource.
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[str] data_source_description: Data Source Description
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] data_source_type: The type of the data source. Valid values:
               
               *   mysql
               - postgresql
               
               *   hdfs
               - hive
        :param pulumi.Input[str] emr_instance_id: The ID of the Emr instance.
        :param pulumi.Input[str] hadoop_core_conf: The string that specifies the content of the Hadoop core-site.xml file.
        :param pulumi.Input[str] hadoop_create_type: The type of the external service. Valid values:
               - emr: E-MapReduce (EMR) Hadoop cluster.
               - selfCreate: self-managed Hadoop cluster.
        :param pulumi.Input[str] hadoop_hosts_address: The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        :param pulumi.Input[str] hdfs_conf: The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] hive_conf: The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        :param pulumi.Input[str] map_reduce_conf: The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] yarn_conf: The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        if data_source_description is not None:
            pulumi.set(__self__, "data_source_description", data_source_description)
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)
        if data_source_type is not None:
            pulumi.set(__self__, "data_source_type", data_source_type)
        if emr_instance_id is not None:
            pulumi.set(__self__, "emr_instance_id", emr_instance_id)
        if hadoop_core_conf is not None:
            pulumi.set(__self__, "hadoop_core_conf", hadoop_core_conf)
        if hadoop_create_type is not None:
            pulumi.set(__self__, "hadoop_create_type", hadoop_create_type)
        if hadoop_hosts_address is not None:
            pulumi.set(__self__, "hadoop_hosts_address", hadoop_hosts_address)
        if hdfs_conf is not None:
            pulumi.set(__self__, "hdfs_conf", hdfs_conf)
        if hive_conf is not None:
            pulumi.set(__self__, "hive_conf", hive_conf)
        if map_reduce_conf is not None:
            pulumi.set(__self__, "map_reduce_conf", map_reduce_conf)
        if yarn_conf is not None:
            pulumi.set(__self__, "yarn_conf", yarn_conf)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[str]:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="dataSourceDescription")
    def data_source_description(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Description
        """
        return pulumi.get(self, "data_source_description")

    @data_source_description.setter
    def data_source_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_description", value)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Name
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_name", value)

    @property
    @pulumi.getter(name="dataSourceType")
    def data_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the data source. Valid values:

        *   mysql
        - postgresql

        *   hdfs
        - hive
        """
        return pulumi.get(self, "data_source_type")

    @data_source_type.setter
    def data_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_type", value)

    @property
    @pulumi.getter(name="emrInstanceId")
    def emr_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Emr instance.
        """
        return pulumi.get(self, "emr_instance_id")

    @emr_instance_id.setter
    def emr_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "emr_instance_id", value)

    @property
    @pulumi.getter(name="hadoopCoreConf")
    def hadoop_core_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop core-site.xml file.
        """
        return pulumi.get(self, "hadoop_core_conf")

    @hadoop_core_conf.setter
    def hadoop_core_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hadoop_core_conf", value)

    @property
    @pulumi.getter(name="hadoopCreateType")
    def hadoop_create_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the external service. Valid values:
        - emr: E-MapReduce (EMR) Hadoop cluster.
        - selfCreate: self-managed Hadoop cluster.
        """
        return pulumi.get(self, "hadoop_create_type")

    @hadoop_create_type.setter
    def hadoop_create_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hadoop_create_type", value)

    @property
    @pulumi.getter(name="hadoopHostsAddress")
    def hadoop_hosts_address(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        """
        return pulumi.get(self, "hadoop_hosts_address")

    @hadoop_hosts_address.setter
    def hadoop_hosts_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hadoop_hosts_address", value)

    @property
    @pulumi.getter(name="hdfsConf")
    def hdfs_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "hdfs_conf")

    @hdfs_conf.setter
    def hdfs_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hdfs_conf", value)

    @property
    @pulumi.getter(name="hiveConf")
    def hive_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        """
        return pulumi.get(self, "hive_conf")

    @hive_conf.setter
    def hive_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hive_conf", value)

    @property
    @pulumi.getter(name="mapReduceConf")
    def map_reduce_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "map_reduce_conf")

    @map_reduce_conf.setter
    def map_reduce_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "map_reduce_conf", value)

    @property
    @pulumi.getter(name="yarnConf")
    def yarn_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "yarn_conf")

    @yarn_conf.setter
    def yarn_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "yarn_conf", value)


@pulumi.input_type
class _HadoopDataSourceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 data_source_description: Optional[pulumi.Input[str]] = None,
                 data_source_id: Optional[pulumi.Input[int]] = None,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 data_source_type: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 emr_instance_id: Optional[pulumi.Input[str]] = None,
                 hadoop_core_conf: Optional[pulumi.Input[str]] = None,
                 hadoop_create_type: Optional[pulumi.Input[str]] = None,
                 hadoop_hosts_address: Optional[pulumi.Input[str]] = None,
                 hdfs_conf: Optional[pulumi.Input[str]] = None,
                 hive_conf: Optional[pulumi.Input[str]] = None,
                 map_reduce_conf: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 yarn_conf: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering HadoopDataSource resources.
        :param pulumi.Input[str] create_time: Creation time
        :param pulumi.Input[str] data_source_description: Data Source Description
        :param pulumi.Input[int] data_source_id: The data source ID.
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] data_source_type: The type of the data source. Valid values:
               
               *   mysql
               - postgresql
               
               *   hdfs
               - hive
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[str] emr_instance_id: The ID of the Emr instance.
        :param pulumi.Input[str] hadoop_core_conf: The string that specifies the content of the Hadoop core-site.xml file.
        :param pulumi.Input[str] hadoop_create_type: The type of the external service. Valid values:
               - emr: E-MapReduce (EMR) Hadoop cluster.
               - selfCreate: self-managed Hadoop cluster.
        :param pulumi.Input[str] hadoop_hosts_address: The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        :param pulumi.Input[str] hdfs_conf: The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] hive_conf: The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        :param pulumi.Input[str] map_reduce_conf: The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] status: Data Source Status
        :param pulumi.Input[str] yarn_conf: The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data_source_description is not None:
            pulumi.set(__self__, "data_source_description", data_source_description)
        if data_source_id is not None:
            pulumi.set(__self__, "data_source_id", data_source_id)
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)
        if data_source_type is not None:
            pulumi.set(__self__, "data_source_type", data_source_type)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if emr_instance_id is not None:
            pulumi.set(__self__, "emr_instance_id", emr_instance_id)
        if hadoop_core_conf is not None:
            pulumi.set(__self__, "hadoop_core_conf", hadoop_core_conf)
        if hadoop_create_type is not None:
            pulumi.set(__self__, "hadoop_create_type", hadoop_create_type)
        if hadoop_hosts_address is not None:
            pulumi.set(__self__, "hadoop_hosts_address", hadoop_hosts_address)
        if hdfs_conf is not None:
            pulumi.set(__self__, "hdfs_conf", hdfs_conf)
        if hive_conf is not None:
            pulumi.set(__self__, "hive_conf", hive_conf)
        if map_reduce_conf is not None:
            pulumi.set(__self__, "map_reduce_conf", map_reduce_conf)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if yarn_conf is not None:
            pulumi.set(__self__, "yarn_conf", yarn_conf)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dataSourceDescription")
    def data_source_description(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Description
        """
        return pulumi.get(self, "data_source_description")

    @data_source_description.setter
    def data_source_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_description", value)

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> Optional[pulumi.Input[int]]:
        """
        The data source ID.
        """
        return pulumi.get(self, "data_source_id")

    @data_source_id.setter
    def data_source_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "data_source_id", value)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Name
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_name", value)

    @property
    @pulumi.getter(name="dataSourceType")
    def data_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the data source. Valid values:

        *   mysql
        - postgresql

        *   hdfs
        - hive
        """
        return pulumi.get(self, "data_source_type")

    @data_source_type.setter
    def data_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_type", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="emrInstanceId")
    def emr_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Emr instance.
        """
        return pulumi.get(self, "emr_instance_id")

    @emr_instance_id.setter
    def emr_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "emr_instance_id", value)

    @property
    @pulumi.getter(name="hadoopCoreConf")
    def hadoop_core_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop core-site.xml file.
        """
        return pulumi.get(self, "hadoop_core_conf")

    @hadoop_core_conf.setter
    def hadoop_core_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hadoop_core_conf", value)

    @property
    @pulumi.getter(name="hadoopCreateType")
    def hadoop_create_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the external service. Valid values:
        - emr: E-MapReduce (EMR) Hadoop cluster.
        - selfCreate: self-managed Hadoop cluster.
        """
        return pulumi.get(self, "hadoop_create_type")

    @hadoop_create_type.setter
    def hadoop_create_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hadoop_create_type", value)

    @property
    @pulumi.getter(name="hadoopHostsAddress")
    def hadoop_hosts_address(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        """
        return pulumi.get(self, "hadoop_hosts_address")

    @hadoop_hosts_address.setter
    def hadoop_hosts_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hadoop_hosts_address", value)

    @property
    @pulumi.getter(name="hdfsConf")
    def hdfs_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "hdfs_conf")

    @hdfs_conf.setter
    def hdfs_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hdfs_conf", value)

    @property
    @pulumi.getter(name="hiveConf")
    def hive_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        """
        return pulumi.get(self, "hive_conf")

    @hive_conf.setter
    def hive_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hive_conf", value)

    @property
    @pulumi.getter(name="mapReduceConf")
    def map_reduce_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "map_reduce_conf")

    @map_reduce_conf.setter
    def map_reduce_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "map_reduce_conf", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Data Source Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="yarnConf")
    def yarn_conf(self) -> Optional[pulumi.Input[str]]:
        """
        The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "yarn_conf")

    @yarn_conf.setter
    def yarn_conf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "yarn_conf", value)


class HadoopDataSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_source_description: Optional[pulumi.Input[str]] = None,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 data_source_type: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 emr_instance_id: Optional[pulumi.Input[str]] = None,
                 hadoop_core_conf: Optional[pulumi.Input[str]] = None,
                 hadoop_create_type: Optional[pulumi.Input[str]] = None,
                 hadoop_hosts_address: Optional[pulumi.Input[str]] = None,
                 hdfs_conf: Optional[pulumi.Input[str]] = None,
                 hive_conf: Optional[pulumi.Input[str]] = None,
                 map_reduce_conf: Optional[pulumi.Input[str]] = None,
                 yarn_conf: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a GPDB Hadoop Data Source resource.

        Hadoop DataSource Config.

        For information about GPDB Hadoop Data Source and how to use it, see [What is Hadoop Data Source](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.230.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default_get_networks = alicloud.vpc.get_networks(name_regex="^default-NODELETING$")
        default_get_switches = alicloud.vpc.get_switches(vpc_id=default_get_networks.ids[0],
            zone_id="cn-beijing-h")
        default_ecs_key_pair = alicloud.ecs.EcsKeyPair("default", key_pair_name=name)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_get_networks.ids[0])
        default_role = alicloud.ram.Role("default",
            name=name,
            document=\"\"\"    {
                "Statement": [
                {
                    "Action": "sts:AssumeRole",
                    "Effect": "Allow",
                    "Principal": {
                    "Service": [
                        "emr.aliyuncs.com",
                        "ecs.aliyuncs.com"
                    ]
                    }
                }
                ],
                "Version": "1"
            }
        \"\"\",
            description="this is a role example.",
            force=True)
        default_get_resource_groups = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_get_keys = alicloud.kms.get_keys(status="Enabled")
        default_cluster = alicloud.emrv2.Cluster("default",
            node_groups=[
                {
                    "vswitch_ids": [default_get_switches.ids[0]],
                    "instance_types": ["ecs.g6.xlarge"],
                    "node_count": 1,
                    "spot_instance_remedy": False,
                    "data_disks": [{
                        "count": 3,
                        "category": "cloud_essd",
                        "size": 80,
                        "performance_level": "PL0",
                    }],
                    "node_group_name": "emr-master",
                    "payment_type": "PayAsYouGo",
                    "with_public_ip": False,
                    "graceful_shutdown": False,
                    "system_disk": {
                        "category": "cloud_essd",
                        "size": 80,
                        "performance_level": "PL0",
                        "count": 1,
                    },
                    "node_group_type": "MASTER",
                },
                {
                    "spot_instance_remedy": False,
                    "node_group_type": "CORE",
                    "vswitch_ids": [default_get_switches.ids[0]],
                    "node_count": 2,
                    "graceful_shutdown": False,
                    "system_disk": {
                        "performance_level": "PL0",
                        "count": 1,
                        "category": "cloud_essd",
                        "size": 80,
                    },
                    "data_disks": [{
                        "count": 3,
                        "performance_level": "PL0",
                        "category": "cloud_essd",
                        "size": 80,
                    }],
                    "node_group_name": "emr-core",
                    "payment_type": "PayAsYouGo",
                    "instance_types": ["ecs.g6.xlarge"],
                    "with_public_ip": False,
                },
            ],
            deploy_mode="NORMAL",
            tags={
                "Created": "TF",
                "For": "example",
            },
            release_version="EMR-5.10.0",
            applications=[
                "HADOOP-COMMON",
                "HDFS",
                "YARN",
            ],
            node_attributes=[{
                "zone_id": "cn-beijing-h",
                "key_pair_name": default_ecs_key_pair.id,
                "data_disk_encrypted": True,
                "data_disk_kms_key_id": default_get_keys.ids[0],
                "vpc_id": default_get_networks.ids[0],
                "ram_role": default_role.name,
                "security_group_id": default_security_group.id,
            }],
            resource_group_id=default_get_resource_groups.ids[0],
            cluster_name=name,
            payment_type="PayAsYouGo",
            cluster_type="DATAFLOW")
        default_zoepvx = alicloud.gpdb.Instance("defaultZoepvx",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=default_get_switches.ids[0],
            storage_size=50,
            master_cu=4,
            vpc_id=default_get_networks.ids[0],
            db_instance_mode="StorageElastic",
            engine="gpdb",
            db_instance_category="Basic")
        defaulty_oxz1_k = alicloud.gpdb.ExternalDataService("defaultyOxz1K",
            service_name=name,
            db_instance_id=default_zoepvx.id,
            service_description=name,
            service_spec="8")
        default_hadoop_data_source = alicloud.gpdb.HadoopDataSource("default",
            hdfs_conf="aaa",
            data_source_name=defaulty_oxz1_k.service_name,
            yarn_conf="aaa",
            hive_conf="aaa",
            hadoop_create_type="emr",
            data_source_description=name,
            map_reduce_conf="aaa",
            data_source_type="hive",
            hadoop_core_conf="aaa",
            emr_instance_id=default_cluster.id,
            db_instance_id=default_zoepvx.id,
            hadoop_hosts_address="aaa")
        ```

        ## Import

        GPDB Hadoop Data Source can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/hadoopDataSource:HadoopDataSource example <db_instance_id>:<data_source_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] data_source_description: Data Source Description
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] data_source_type: The type of the data source. Valid values:
               
               *   mysql
               - postgresql
               
               *   hdfs
               - hive
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[str] emr_instance_id: The ID of the Emr instance.
        :param pulumi.Input[str] hadoop_core_conf: The string that specifies the content of the Hadoop core-site.xml file.
        :param pulumi.Input[str] hadoop_create_type: The type of the external service. Valid values:
               - emr: E-MapReduce (EMR) Hadoop cluster.
               - selfCreate: self-managed Hadoop cluster.
        :param pulumi.Input[str] hadoop_hosts_address: The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        :param pulumi.Input[str] hdfs_conf: The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] hive_conf: The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        :param pulumi.Input[str] map_reduce_conf: The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] yarn_conf: The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HadoopDataSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GPDB Hadoop Data Source resource.

        Hadoop DataSource Config.

        For information about GPDB Hadoop Data Source and how to use it, see [What is Hadoop Data Source](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.230.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default_get_networks = alicloud.vpc.get_networks(name_regex="^default-NODELETING$")
        default_get_switches = alicloud.vpc.get_switches(vpc_id=default_get_networks.ids[0],
            zone_id="cn-beijing-h")
        default_ecs_key_pair = alicloud.ecs.EcsKeyPair("default", key_pair_name=name)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_get_networks.ids[0])
        default_role = alicloud.ram.Role("default",
            name=name,
            document=\"\"\"    {
                "Statement": [
                {
                    "Action": "sts:AssumeRole",
                    "Effect": "Allow",
                    "Principal": {
                    "Service": [
                        "emr.aliyuncs.com",
                        "ecs.aliyuncs.com"
                    ]
                    }
                }
                ],
                "Version": "1"
            }
        \"\"\",
            description="this is a role example.",
            force=True)
        default_get_resource_groups = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_get_keys = alicloud.kms.get_keys(status="Enabled")
        default_cluster = alicloud.emrv2.Cluster("default",
            node_groups=[
                {
                    "vswitch_ids": [default_get_switches.ids[0]],
                    "instance_types": ["ecs.g6.xlarge"],
                    "node_count": 1,
                    "spot_instance_remedy": False,
                    "data_disks": [{
                        "count": 3,
                        "category": "cloud_essd",
                        "size": 80,
                        "performance_level": "PL0",
                    }],
                    "node_group_name": "emr-master",
                    "payment_type": "PayAsYouGo",
                    "with_public_ip": False,
                    "graceful_shutdown": False,
                    "system_disk": {
                        "category": "cloud_essd",
                        "size": 80,
                        "performance_level": "PL0",
                        "count": 1,
                    },
                    "node_group_type": "MASTER",
                },
                {
                    "spot_instance_remedy": False,
                    "node_group_type": "CORE",
                    "vswitch_ids": [default_get_switches.ids[0]],
                    "node_count": 2,
                    "graceful_shutdown": False,
                    "system_disk": {
                        "performance_level": "PL0",
                        "count": 1,
                        "category": "cloud_essd",
                        "size": 80,
                    },
                    "data_disks": [{
                        "count": 3,
                        "performance_level": "PL0",
                        "category": "cloud_essd",
                        "size": 80,
                    }],
                    "node_group_name": "emr-core",
                    "payment_type": "PayAsYouGo",
                    "instance_types": ["ecs.g6.xlarge"],
                    "with_public_ip": False,
                },
            ],
            deploy_mode="NORMAL",
            tags={
                "Created": "TF",
                "For": "example",
            },
            release_version="EMR-5.10.0",
            applications=[
                "HADOOP-COMMON",
                "HDFS",
                "YARN",
            ],
            node_attributes=[{
                "zone_id": "cn-beijing-h",
                "key_pair_name": default_ecs_key_pair.id,
                "data_disk_encrypted": True,
                "data_disk_kms_key_id": default_get_keys.ids[0],
                "vpc_id": default_get_networks.ids[0],
                "ram_role": default_role.name,
                "security_group_id": default_security_group.id,
            }],
            resource_group_id=default_get_resource_groups.ids[0],
            cluster_name=name,
            payment_type="PayAsYouGo",
            cluster_type="DATAFLOW")
        default_zoepvx = alicloud.gpdb.Instance("defaultZoepvx",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=default_get_switches.ids[0],
            storage_size=50,
            master_cu=4,
            vpc_id=default_get_networks.ids[0],
            db_instance_mode="StorageElastic",
            engine="gpdb",
            db_instance_category="Basic")
        defaulty_oxz1_k = alicloud.gpdb.ExternalDataService("defaultyOxz1K",
            service_name=name,
            db_instance_id=default_zoepvx.id,
            service_description=name,
            service_spec="8")
        default_hadoop_data_source = alicloud.gpdb.HadoopDataSource("default",
            hdfs_conf="aaa",
            data_source_name=defaulty_oxz1_k.service_name,
            yarn_conf="aaa",
            hive_conf="aaa",
            hadoop_create_type="emr",
            data_source_description=name,
            map_reduce_conf="aaa",
            data_source_type="hive",
            hadoop_core_conf="aaa",
            emr_instance_id=default_cluster.id,
            db_instance_id=default_zoepvx.id,
            hadoop_hosts_address="aaa")
        ```

        ## Import

        GPDB Hadoop Data Source can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/hadoopDataSource:HadoopDataSource example <db_instance_id>:<data_source_id>
        ```

        :param str resource_name: The name of the resource.
        :param HadoopDataSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HadoopDataSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_source_description: Optional[pulumi.Input[str]] = None,
                 data_source_name: Optional[pulumi.Input[str]] = None,
                 data_source_type: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 emr_instance_id: Optional[pulumi.Input[str]] = None,
                 hadoop_core_conf: Optional[pulumi.Input[str]] = None,
                 hadoop_create_type: Optional[pulumi.Input[str]] = None,
                 hadoop_hosts_address: Optional[pulumi.Input[str]] = None,
                 hdfs_conf: Optional[pulumi.Input[str]] = None,
                 hive_conf: Optional[pulumi.Input[str]] = None,
                 map_reduce_conf: Optional[pulumi.Input[str]] = None,
                 yarn_conf: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HadoopDataSourceArgs.__new__(HadoopDataSourceArgs)

            __props__.__dict__["data_source_description"] = data_source_description
            __props__.__dict__["data_source_name"] = data_source_name
            __props__.__dict__["data_source_type"] = data_source_type
            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            __props__.__dict__["emr_instance_id"] = emr_instance_id
            __props__.__dict__["hadoop_core_conf"] = hadoop_core_conf
            __props__.__dict__["hadoop_create_type"] = hadoop_create_type
            __props__.__dict__["hadoop_hosts_address"] = hadoop_hosts_address
            __props__.__dict__["hdfs_conf"] = hdfs_conf
            __props__.__dict__["hive_conf"] = hive_conf
            __props__.__dict__["map_reduce_conf"] = map_reduce_conf
            __props__.__dict__["yarn_conf"] = yarn_conf
            __props__.__dict__["create_time"] = None
            __props__.__dict__["data_source_id"] = None
            __props__.__dict__["status"] = None
        super(HadoopDataSource, __self__).__init__(
            'alicloud:gpdb/hadoopDataSource:HadoopDataSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            data_source_description: Optional[pulumi.Input[str]] = None,
            data_source_id: Optional[pulumi.Input[int]] = None,
            data_source_name: Optional[pulumi.Input[str]] = None,
            data_source_type: Optional[pulumi.Input[str]] = None,
            db_instance_id: Optional[pulumi.Input[str]] = None,
            emr_instance_id: Optional[pulumi.Input[str]] = None,
            hadoop_core_conf: Optional[pulumi.Input[str]] = None,
            hadoop_create_type: Optional[pulumi.Input[str]] = None,
            hadoop_hosts_address: Optional[pulumi.Input[str]] = None,
            hdfs_conf: Optional[pulumi.Input[str]] = None,
            hive_conf: Optional[pulumi.Input[str]] = None,
            map_reduce_conf: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            yarn_conf: Optional[pulumi.Input[str]] = None) -> 'HadoopDataSource':
        """
        Get an existing HadoopDataSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: Creation time
        :param pulumi.Input[str] data_source_description: Data Source Description
        :param pulumi.Input[int] data_source_id: The data source ID.
        :param pulumi.Input[str] data_source_name: Data Source Name
        :param pulumi.Input[str] data_source_type: The type of the data source. Valid values:
               
               *   mysql
               - postgresql
               
               *   hdfs
               - hive
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[str] emr_instance_id: The ID of the Emr instance.
        :param pulumi.Input[str] hadoop_core_conf: The string that specifies the content of the Hadoop core-site.xml file.
        :param pulumi.Input[str] hadoop_create_type: The type of the external service. Valid values:
               - emr: E-MapReduce (EMR) Hadoop cluster.
               - selfCreate: self-managed Hadoop cluster.
        :param pulumi.Input[str] hadoop_hosts_address: The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        :param pulumi.Input[str] hdfs_conf: The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] hive_conf: The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        :param pulumi.Input[str] map_reduce_conf: The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        :param pulumi.Input[str] status: Data Source Status
        :param pulumi.Input[str] yarn_conf: The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HadoopDataSourceState.__new__(_HadoopDataSourceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data_source_description"] = data_source_description
        __props__.__dict__["data_source_id"] = data_source_id
        __props__.__dict__["data_source_name"] = data_source_name
        __props__.__dict__["data_source_type"] = data_source_type
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["emr_instance_id"] = emr_instance_id
        __props__.__dict__["hadoop_core_conf"] = hadoop_core_conf
        __props__.__dict__["hadoop_create_type"] = hadoop_create_type
        __props__.__dict__["hadoop_hosts_address"] = hadoop_hosts_address
        __props__.__dict__["hdfs_conf"] = hdfs_conf
        __props__.__dict__["hive_conf"] = hive_conf
        __props__.__dict__["map_reduce_conf"] = map_reduce_conf
        __props__.__dict__["status"] = status
        __props__.__dict__["yarn_conf"] = yarn_conf
        return HadoopDataSource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Creation time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataSourceDescription")
    def data_source_description(self) -> pulumi.Output[Optional[str]]:
        """
        Data Source Description
        """
        return pulumi.get(self, "data_source_description")

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> pulumi.Output[int]:
        """
        The data source ID.
        """
        return pulumi.get(self, "data_source_id")

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> pulumi.Output[Optional[str]]:
        """
        Data Source Name
        """
        return pulumi.get(self, "data_source_name")

    @property
    @pulumi.getter(name="dataSourceType")
    def data_source_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of the data source. Valid values:

        *   mysql
        - postgresql

        *   hdfs
        - hive
        """
        return pulumi.get(self, "data_source_type")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[str]:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter(name="emrInstanceId")
    def emr_instance_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the Emr instance.
        """
        return pulumi.get(self, "emr_instance_id")

    @property
    @pulumi.getter(name="hadoopCoreConf")
    def hadoop_core_conf(self) -> pulumi.Output[Optional[str]]:
        """
        The string that specifies the content of the Hadoop core-site.xml file.
        """
        return pulumi.get(self, "hadoop_core_conf")

    @property
    @pulumi.getter(name="hadoopCreateType")
    def hadoop_create_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of the external service. Valid values:
        - emr: E-MapReduce (EMR) Hadoop cluster.
        - selfCreate: self-managed Hadoop cluster.
        """
        return pulumi.get(self, "hadoop_create_type")

    @property
    @pulumi.getter(name="hadoopHostsAddress")
    def hadoop_hosts_address(self) -> pulumi.Output[Optional[str]]:
        """
        The IP address and hostname of the Hadoop cluster (data source) in the /etc/hosts file.
        """
        return pulumi.get(self, "hadoop_hosts_address")

    @property
    @pulumi.getter(name="hdfsConf")
    def hdfs_conf(self) -> pulumi.Output[Optional[str]]:
        """
        The string that specifies the content of the Hadoop hdfs-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "hdfs_conf")

    @property
    @pulumi.getter(name="hiveConf")
    def hive_conf(self) -> pulumi.Output[Optional[str]]:
        """
        The string that specifies the content of the Hadoop hive-site.xml file. This parameter must be specified when DataSourceType is set to Hive.
        """
        return pulumi.get(self, "hive_conf")

    @property
    @pulumi.getter(name="mapReduceConf")
    def map_reduce_conf(self) -> pulumi.Output[Optional[str]]:
        """
        The content of the Hadoop mapred-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "map_reduce_conf")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Data Source Status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="yarnConf")
    def yarn_conf(self) -> pulumi.Output[Optional[str]]:
        """
        The string that specifies the content of the Hadoop yarn-site.xml file. This parameter must be specified when DataSourceType is set to HDFS.
        """
        return pulumi.get(self, "yarn_conf")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] name: . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        :param pulumi.Input[str] policy: Log project policy, used to set a policy for a project.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
               - The project name must be globally unique.
               - The name can contain only lowercase letters, digits, and hyphens (-).
               - It must start and end with a lowercase letter or number.
               - The value contains 3 to 63 characters.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Tag.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""")
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        Log project policy, used to set a policy for a project.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
        - The project name must be globally unique.
        - The name can contain only lowercase letters, digits, and hyphens (-).
        - It must start and end with a lowercase letter or number.
        - The value contains 3 to 63 characters.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Tag.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[str] create_time: CreateTime.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] name: . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        :param pulumi.Input[str] policy: Log project policy, used to set a policy for a project.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
               - The project name must be globally unique.
               - The name can contain only lowercase letters, digits, and hyphens (-).
               - It must start and end with a lowercase letter or number.
               - The value contains 3 to 63 characters.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Tag.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        CreateTime.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""")
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        Log project policy, used to set a policy for a project.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
        - The project name must be globally unique.
        - The name can contain only lowercase letters, digits, and hyphens (-).
        - It must start and end with a lowercase letter or number.
        - The value contains 3 to 63 characters.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Tag.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a SLS Project resource.

        For information about SLS Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/sls/developer-reference/api-createproject).

        > **NOTE:** Available since v1.9.5.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example = alicloud.log.Project("example",
            project_name=f"terraform-example-{default['result']}",
            description="terraform-example",
            tags={
                "Created": "TF",
                "For": "example",
            })
        ```

        Project With Policy Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example_policy = alicloud.log.Project("example_policy",
            project_name=f"terraform-example-{default['result']}",
            description="terraform-example",
            policy=\"\"\"{
          "Statement": [
            {
              "Action": [
                "log:PostLogStoreLogs"
              ],
              "Condition": {
                "StringNotLike": {
                  "acs:SourceVpc": [
                    "vpc-*"
                  ]
                }
              },
              "Effect": "Deny",
              "Resource": "acs:log:*:*:project/tf-log/*"
            }
          ],
          "Version": "1"
        }
        \"\"\")
        ```

        ## Module Support

        You can use the existing sls module
        to create SLS project, store and store index one-click, like ECS instances.

        ## Import

        SLS Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:log/project:Project example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] name: . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        :param pulumi.Input[str] policy: Log project policy, used to set a policy for a project.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
               - The project name must be globally unique.
               - The name can contain only lowercase letters, digits, and hyphens (-).
               - It must start and end with a lowercase letter or number.
               - The value contains 3 to 63 characters.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Tag.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a SLS Project resource.

        For information about SLS Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/sls/developer-reference/api-createproject).

        > **NOTE:** Available since v1.9.5.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example = alicloud.log.Project("example",
            project_name=f"terraform-example-{default['result']}",
            description="terraform-example",
            tags={
                "Created": "TF",
                "For": "example",
            })
        ```

        Project With Policy Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example_policy = alicloud.log.Project("example_policy",
            project_name=f"terraform-example-{default['result']}",
            description="terraform-example",
            policy=\"\"\"{
          "Statement": [
            {
              "Action": [
                "log:PostLogStoreLogs"
              ],
              "Condition": {
                "StringNotLike": {
                  "acs:SourceVpc": [
                    "vpc-*"
                  ]
                }
              },
              "Effect": "Deny",
              "Resource": "acs:log:*:*:project/tf-log/*"
            }
          ],
          "Version": "1"
        }
        \"\"\")
        ```

        ## Module Support

        You can use the existing sls module
        to create SLS project, store and store index one-click, like ECS instances.

        ## Import

        SLS Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:log/project:Project example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["policy"] = policy
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Project, __self__).__init__(
            'alicloud:log/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            policy: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: CreateTime.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] name: . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        :param pulumi.Input[str] policy: Log project policy, used to set a policy for a project.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
               - The project name must be globally unique.
               - The name can contain only lowercase letters, digits, and hyphens (-).
               - It must start and end with a lowercase letter or number.
               - The value contains 3 to 63 characters.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Tag.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["policy"] = policy
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        CreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated since provider version 1.223.0. New field 'project_name' instead.""")
    def name(self) -> pulumi.Output[str]:
        """
        . Field 'name' has been deprecated from provider version 1.223.0. New field 'project_name' instead.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[Optional[str]]:
        """
        Log project policy, used to set a policy for a project.
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        The name of the log project. It is the only in one Alicloud account. The project name is globally unique in Alibaba Cloud and cannot be modified after it is created. The naming rules are as follows:
        - The project name must be globally unique.
        - The name can contain only lowercase letters, digits, and hyphens (-).
        - It must start and end with a lowercase letter or number.
        - The value contains 3 to 63 characters.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Tag.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "tags")

